The Briefcase Developer and User community
==========================================

Briefcase is part of the `BeeWare suite`_. You can talk to the community
through:

* `@beeware@fosstodon.org on Mastodon <https://fosstodon.org/@beeware>`__
* `Discord <https://beeware.org/bee/chat/>`__
* `BeeWare Getting Help page <https://beeware.org/community/getting-help/>`__

Code of Conduct
---------------

The BeeWare community has a strict `Code of Conduct`_. All users and developers
are expected to adhere to this code.

If you have any concerns about this code of conduct, or you wish to report a
violation of this code, please contact the project founder `Russell
Keith-Magee`_.

Contributing
------------

If you experience problems with Briefcase, `log them on GitHub`_. If you want
to contribute code, please `fork the code`_ and `submit a pull request`_.

.. _BeeWare suite: https://beeware.org
.. _Read The Docs: https://briefcase.readthedocs.io
.. _log them on Github: https://github.com/beeware/briefcase/issues
.. _fork the code: https://github.com/beeware/briefcase
.. _submit a pull request: https://github.com/beeware/briefcase/pulls
.. _Code of Conduct: https://beeware.org/contributing/index.html
.. _Russell Keith-Magee: russell@keith-magee.com
